## Usage

```
r6t7 .
```

this will run the updater tool in the current directory. 

During the merging portion of the `rails app:update` command, vim buffers will open up showing you the
merge

If you wish you use another editor like VS Code or Sublime Text to handle merges, you can specify them as an option:

```
r6t7 . subl 
```